=== modified file 'bzrlib/tests/matchers.py'
--- bzrlib/tests/matchers.py	2010-05-06 11:08:10 +0000
+++ bzrlib/tests/matchers.py	2010-05-06 07:48:22 +0000
@@ -27,17 +27,17 @@
 """
 
 __all__ = [
-    'ReturnsUnlockable',
+    'ReturnsCallableLeavingObjectUnlocked',
     ]
 
 from testtools.matchers import Mismatch, Matcher
 
 
-class ReturnsUnlockable(Matcher):
+class ReturnsCallableLeavingObjectUnlocked(Matcher):
     """A matcher that checks for the pattern we want lock* methods to have:
 
-    They should return an object with an unlock() method.
-    Calling that method should unlock the original object.
+    They should return a callable.
+    Calling that callable should unlock the original object.
 
     :ivar lockable_thing: The object which can be locked that will be
         inspected.
@@ -48,11 +48,11 @@
         self.lockable_thing = lockable_thing
 
     def __str__(self):
-        return ('ReturnsUnlockable(lockable_thing=%s)' % 
+        return ('ReturnsCallableLeavingObjectUnlocked(lockable_thing=%s)' % 
             self.lockable_thing)
 
     def match(self, lock_method):
-        lock_method().unlock()
+        lock_method()()
         if self.lockable_thing.is_locked():
             return _IsLocked(self.lockable_thing)
         return None

=== modified file 'bzrlib/tests/test_matchers.py'
--- bzrlib/tests/test_matchers.py	2010-05-06 11:08:10 +0000
+++ bzrlib/tests/test_matchers.py	2010-05-06 07:48:22 +0000
@@ -35,30 +35,23 @@
         return self._is_locked
 
 
-class FakeUnlockable(object):
-    """Something that can be unlocked."""
-
-    def unlock(self):
-        pass
-
-
-class TestReturnsUnlockable(TestCase):
+class TestReturnsCallableLeavingObjectUnlocked(TestCase):
 
     def test___str__(self):
-        matcher = ReturnsUnlockable(StubTree(True))
+        matcher = ReturnsCallableLeavingObjectUnlocked(StubTree(True))
         self.assertEqual(
-            'ReturnsUnlockable(lockable_thing=I am da tree)',
+            'ReturnsCallableLeavingObjectUnlocked(lockable_thing=I am da tree)',
             str(matcher))
 
     def test_match(self):
         stub_tree = StubTree(False)
-        matcher = ReturnsUnlockable(stub_tree)
-        self.assertThat(matcher.match(lambda:FakeUnlockable()), Equals(None))
+        matcher = ReturnsCallableLeavingObjectUnlocked(stub_tree)
+        self.assertThat(matcher.match(lambda:lambda:None), Equals(None))
 
     def test_mismatch(self):
         stub_tree = StubTree(True)
-        matcher = ReturnsUnlockable(stub_tree)
-        mismatch = matcher.match(lambda:FakeUnlockable())
+        matcher = ReturnsCallableLeavingObjectUnlocked(stub_tree)
+        mismatch = matcher.match(lambda:lambda:None)
         self.assertNotEqual(None, mismatch)
         self.assertThat(mismatch.describe(), Equals("I am da tree is locked"))
 

